{% extends "admin/base_site.html" %}
{% load i18n %}

{% block breadcrumbs %}
<div class="breadcrumbs">
     <a href="../../">{% trans "Home" %}</a> &rsaquo;
     <a href="../">{{ app_label|capfirst }}</a> &rsaquo;
     <a href="./">{{ opts.verbose_name_plural|capfirst }}</a>
</div>
{% endblock %}

{% block content %}
	<h1>{% trans 'Sorry, but deleting impostor logs is forbidden! ' %}</h1>
{% endblock %}
