{% extends "admin/change_list.html" %}
{% load admin_list i18n %}

{% block extrahead %}
{{ block.super }}
{{ media.js }}
<style type="text/css">
tr td:first-child, tr th:first-child {display:none;}
</style>
{% endblock %}

{% block object-tools %}
{% endblock %}
