"""Impostor."""
__version__ = "3.1.0"
__author__ = "Marko Samastur"
__email__ = "markos@gaivo.net"
__mantainer__ = "Andreu Vallbona"
__mantainer_email__ = "avallbona@gmail.com"
default_app_config = "impostor.apps.ImpostorConfig"
